<?php

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function toocheke_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Right Sidebar', 'toocheke' ),
		'id'            => 'right-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'toocheke' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'toocheke_widgets_init' );

/*
* About Widget
*/
if ( ! function_exists( 'toocheke_load_about_widget' ) ) :
	function toocheke_load_about_widget() {
		register_widget( 'toocheke_about_widget' );
	}
	endif;
	add_action( 'widgets_init', 'toocheke_load_about_widget' );
	
	if ( ! class_exists( 'toocheke_about_widget' ) ) :
	class toocheke_about_widget extends WP_Widget
	{
	
		public function __construct()
		{
			$widget_details = array(
				'classname' => 'toocheke_about_widget',
				'description' => esc_html__('Creates an about section consisting of a title, image/avatar, and a description. Ideal for the right sidebar on the Toocheke WP theme.', 'toocheke' )
			);
	
			parent::__construct( 'toocheke_about_widget', 'Toocheke: About Us', $widget_details );
	
			add_action('admin_enqueue_scripts', array($this, 'toocheke_about_us_widget_assets'));
		}
	
	
	public function toocheke_about_us_widget_assets()
	{
		wp_enqueue_script('media-upload');
		wp_enqueue_script('thickbox');
		wp_enqueue_script( 'toocheke-bootstrap', get_template_directory_uri() . '/dist/js/toocheke-media-upload.js', array('jquery'), '20190508', true );
		wp_enqueue_style('thickbox');
	}
	
	
		public function widget( $args, $instance )
		{
			$allowed_tags = array(
				'section' => array(
						'id' => array(),
						'class' => array()
				),
				'h4' => array(
					'class' => array()
				)
			);
			echo wp_kses($args['before_widget'], $allowed_tags);
			if ( ! empty( $instance['title'] ) ) {
				$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
				$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
				echo wp_kses($args['before_title'], $allowed_tags) . wp_kses($title, $allowed_tags). wp_kses($args['after_title'], $allowed_tags);
			}
	
			?>
			<img src='<?php echo esc_attr($instance['image']) ?>' class='about-avatar' >
			
				<?php echo wp_kses_data(wpautop( esc_html( $instance['description'] ) )) ?>
		
	
		
	
			<?php
	
			echo wp_kses($args['after_widget'], $allowed_tags);
		}
	
		public function update( $new_instance, $old_instance ) {  
			$instance = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
			$instance['description'] = ( ! empty( $new_instance['description'] ) ) ? sanitize_textarea_field( $new_instance['description'] ) : '';
			$instance['image'] = ( ! empty( $new_instance['image'] ) ) ? sanitize_text_field( $new_instance['image'] ) : '';
			return $instance;
		}
	
		public function form( $instance )
		{
	
			$title = '';
			if( !empty( $instance['title'] ) ) {
				$title = $instance['title'];
			}
	
			$description = '';
			if( !empty( $instance['description'] ) ) {
				$description = $instance['description'];
			}
	
	
			$image = '';
			if(isset($instance['image']))
			{
				$image = $instance['image'];
			}
			?>
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'title' )); ?>"><?php esc_html_e( 'Title:' , 'toocheke' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</p>
	
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'description' )); ?>"><?php esc_html_e( 'Description:' , 'toocheke' ); ?></label>
				<textarea class="widefat" id="<?php echo esc_attr($this->get_field_id( 'description' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'description' )); ?>" type="text" ><?php echo esc_attr( $description ); ?></textarea>
			</p>
	
	
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'image' )); ?>"><?php esc_html_e( 'Image:' , 'toocheke' ); ?></label>
				<input name="<?php echo esc_attr($this->get_field_name( 'image' )); ?>" id="<?php echo esc_attr($this->get_field_id( 'image' )); ?>" class="widefat" type="text" size="36"  value="<?php echo esc_url( $image ); ?>" />
				<input class="upload_image_button" type="button" value="Upload Image" />
			</p>
		<?php
		}
	}
	endif;
	//About Us Widget ends here
	
	/*
	* Social Media Widget
	*/
	
	
	
	if ( ! function_exists( 'toocheke_load_social_media' ) ) :
	function toocheke_load_social_media() {
		register_widget( 'toocheke_social_media' );
	}
	endif;
	add_action( 'widgets_init', 'toocheke_load_social_media' );
	
	if ( ! class_exists( 'toocheke_social_media' ) ) :
	class toocheke_social_media extends WP_Widget
	{
	
		public function __construct()
		{
			$widget_details = array(
				'classname' => 'toocheke_social_media social-links',
				'description' => esc_html__('Add links to your social media profiles. Ideally for the right sidebar on the Toocheke WP theme. ', 'toocheke' )
			);
	
			parent::__construct( 'toocheke_social_media', 'Toocheke: Social', $widget_details );
	
	
		}
	
	
		public function widget( $args, $instance )
		{
			$allowed_tags = array(
				'section' => array(
						'id' => array(),
						'class' => array()
				),
				'h4' => array(
					'class' => array()
				)
			);
			echo wp_kses($args['before_widget'], $allowed_tags);
			if ( ! empty( $instance['title'] ) ) {
				$title = ! empty( $instance['title'] ) ? $instance['title'] : '';
				$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
				echo wp_kses($args['before_title'], $allowed_tags) . wp_kses($title, $allowed_tags). wp_kses($args['after_title'], $allowed_tags);
			}
			?>
			<ul>
			<?php if ( ! empty( $instance['patreon_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['patreon_url']) ?>' title="Patreon"><span class="fab fa-md fa-patreon"></span></a></li>
			<?php } if ( ! empty( $instance['webtoon_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['webtoon_url']) ?>' title="Line Webtoon"><span class="fab fa-md fa-line"></span></a></li>
		<?php } if ( ! empty( $instance['instagram_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['instagram_url']) ?>' title="Instagram"><span class="fab fa-md fa-instagram"></span></a></li>
		<?php } if ( ! empty( $instance['twitter_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['twitter_url']) ?>' title="Twitter"><span class="fab fa-md fa-twitter"></span></a></li>
		<?php } if ( ! empty( $instance['facebook_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['facebook_url']) ?>' title="Facebook"><span class="fab fa-md fa-facebook-f"></span></a></li>
		<?php } if ( ! empty( $instance['reddit_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['reddit_url']) ?>' title="Reddit"><span class="fab fa-md fa-reddit-alien"></span></a></li>
		<?php } if ( ! empty( $instance['linkedin_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['linkedin_url']) ?>' title="LinkedIn"><span class="fab fa-md fa-linkedin-in"></span></a></li>
		<?php } if ( ! empty( $instance['tumblr_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['tumblr_url']) ?>' title="Tumblr"><span class="fab fa-md fa-tumblr"></span></a></li>
		<?php } if ( ! empty( $instance['youtube_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['youtube_url']) ?>' title="Youtube"><span class="fab fa-md fa-youtube"></span></a></li>
		<?php } if ( ! empty( $instance['twitch_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['twitch_url']) ?>' title="Twitch"><span class="fab fa-md fa-twitch"></span></a></li>
		<?php } if ( ! empty( $instance['rss_url'] ) ) { ?>
		<li class="line"><a target="_blank" href='<?php echo esc_attr($instance['rss_url']) ?>' title="RSS"><span class="fas fa-md fa-rss"></span></a></li>
	<?php } ?>
	</ul>
	
	
	
	
	
		
	
			<?php
	
			echo wp_kses($args['after_widget'], $allowed_tags);
		}
	
		public function update( $new_instance, $old_instance ) {  
			$instance = array();
			$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
			$instance['patreon_url'] = ( ! empty( $new_instance['patreon_url'] ) ) ? esc_url_raw( $new_instance['patreon_url'] ) : '';
			$instance['webtoon_url'] = ( ! empty( $new_instance['webtoon_url'] ) ) ? esc_url_raw( $new_instance['webtoon_url'] ) : '';
			$instance['instagram_url'] = ( ! empty( $new_instance['instagram_url'] ) ) ? esc_url_raw( $new_instance['instagram_url'] ) : '';
			$instance['twitter_url'] = ( ! empty( $new_instance['twitter_url'] ) ) ? esc_url_raw( $new_instance['twitter_url'] ) : '';
			$instance['facebook_url'] = ( ! empty( $new_instance['facebook_url'] ) ) ? esc_url_raw( $new_instance['facebook_url'] ) : '';
			$instance['reddit_url'] = ( ! empty( $new_instance['reddit_url'] ) ) ? esc_url_raw( $new_instance['reddit_url'] ) : '';
			$instance['linkedin_url'] = ( ! empty( $new_instance['linkedin_url'] ) ) ? esc_url_raw( $new_instance['linkedin_url'] ) : '';
			$instance['tumblr_url'] = ( ! empty( $new_instance['tumblr_url'] ) ) ? esc_url_raw( $new_instance['tumblr_url'] ) : '';
			$instance['youtube_url'] = ( ! empty( $new_instance['youtube_url'] ) ) ? esc_url_raw( $new_instance['youtube_url'] ) : '';
			$instance['twitch_url'] = ( ! empty( $new_instance['twitch_url'] ) ) ? esc_url_raw( $new_instance['twitch_url'] ) : '';
			$instance['rss_url'] = ( ! empty( $new_instance['rss_url'] ) ) ? esc_url_raw( $new_instance['rss_url'] ) : '';
			return $instance;
		}
	
		public function form( $instance )
		{
	
			$title = '';
			if( !empty( $instance['title'] ) ) {
				$title = $instance['title'];
			}
	
			$patreon_url = '';
			if( !empty( $instance['patreon_url'] ) ) {
				$patreon_url = $instance['patreon_url'];
			}
			
			
	
	
			 $webtoon_url = '';
			if( !empty( $instance['webtoon_url'] ) ) {
				$webtoon_url = $instance['webtoon_url'];
			}
			
			 $instagram_url = '';
			if( !empty( $instance['instagram_url'] ) ) {
				$instagram_url = $instance['instagram_url'];
			}
			 $twitter_url = '';
			if( !empty( $instance['twitter_url'] ) ) {
				$twitter_url = $instance['twitter_url'];
			}
			 $facebook_url = '';
			if( !empty( $instance['facebook_url'] ) ) {
				$facebook_url = $instance['facebook_url'];
			}
			
			$reddit_url = '';
			if( !empty( $instance['reddit_url'] ) ) {
				$reddit_url = $instance['reddit_url'];
			}
			
			$linkedin_url = '';
			if( !empty( $instance['linkedin_url'] ) ) {
				$linkedin_url = $instance['linkedin_url'];
			}
			
			$tumblr_url = '';
			if( !empty( $instance['tumblr_url'] ) ) {
				$tumblr_url = $instance['tumblr_url'];
			}
			
			$youtube_url = '';
			if( !empty( $instance['youtube_url'] ) ) {
				$youtube_url = $instance['youtube_url'];
			}
			$twitch_url = '';
			if( !empty( $instance['twitch_url'] ) ) {
				$twitch_url = $instance['twitch_url'];
			}
			
			$rss_url = '';
			if( !empty( $instance['rss_url'] ) ) {
				$rss_url = $instance['rss_url'];
			}
			?>
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'title' )); ?>"><?php esc_html_e( 'Title:' , 'toocheke' ); ?></label>
				<input class="widefat" placeholder="About Us Title" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</p>
	
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'patreon_url' )); ?>"><?php esc_html_e( 'Patreon URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'patreon_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'patreon_url' )); ?>" type="text" value="<?php echo esc_attr( $patreon_url ); ?>" />
			</p>
	
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'webtoon_url' )); ?>"><?php esc_html_e( 'LINE Webtoon URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'webtoon_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'webtoon_url' )); ?>" type="text" value="<?php echo esc_attr( $webtoon_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'instagram_url' )); ?>"><?php esc_html_e( 'Intagram URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'instagram_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'instagram_url' )); ?>" type="text" value="<?php echo esc_attr( $instagram_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'twitter_url' )); ?>"><?php esc_html_e( 'Twitter URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'twitter_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'twitter_url' )); ?>" type="text" value="<?php echo esc_attr( $twitter_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'facebook_url' )); ?>"><?php esc_html_e( 'Facebook URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'facebook_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'facebook_url' )); ?>" type="text" value="<?php echo esc_attr( $facebook_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'reddit_url' )); ?>"><?php esc_html_e( 'Reddit URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'reddit_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'reddit_url' )); ?>" type="text" value="<?php echo esc_attr( $reddit_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'linkedin_url' )); ?>"><?php esc_html_e( 'LinkedIn URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'linkedin_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'linkedin_url' )); ?>" type="text" value="<?php echo esc_attr( $linkedin_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'tumblr_url' )); ?>"><?php esc_html_e( 'Tumblr URL:'  , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'tumblr_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'tumblr_url' )); ?>" type="text" value="<?php echo esc_attr( $tumblr_url ); ?>" />
			</p>
			 <p>
				<label for="<?php echo esc_attr($this->get_field_name( 'youtube_url' )); ?>"><?php esc_html_e( 'Youtube URL:' , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'youtube_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'youtube_url' )); ?>" type="text" value="<?php echo esc_attr( $youtube_url ); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'twitch_url' )); ?>"><?php esc_html_e( 'Twitch URL:' , 'toocheke'); ?></label>
				<input class="widefat" placeholder="https://www.example.com" id="<?php echo esc_attr($this->get_field_id( 'twitch_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'twitch_url' )); ?>" type="text" value="<?php echo esc_attr( $twitch_url ); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_name( 'rss_url' )); ?>"><?php esc_html_e( 'Comics RSS URL(e.g. https://www.yourdomain.com/comics/feed):' , 'toocheke'); ?></label>
				<input class="widefat" placeholder="<?php echo esc_url(site_url()) . "/comics/feed" ?>" id="<?php echo esc_attr($this->get_field_id( 'rss_url' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'rss_url' )); ?>" type="text" value="<?php echo esc_attr( $rss_url ); ?>" />
			</p>
			
	
	
	
		<?php
		}
	}
	endif;
	//Social Media Widget ends here
